#ifndef __MiscTableScrollInspector_h
#define __MiscTableScrollInspector_h
//=============================================================================
//
//	Copyright (C) 1995-1999 by Paul S. McCarthy and Eric Sunshine.
//		Written by Paul S. McCarthy and Eric Sunshine.
//			    All Rights Reserved.
//
//	This notice may not be removed from this source code.
//
//	This object is included in the MiscKit by permission from the authors
//	and its use is governed by the MiscKit license, found in the file
//	"License.rtf" in the MiscKit distribution.  Please refer to that file
//	for a list of all applicable permissions and restrictions.
//	
//=============================================================================
//-----------------------------------------------------------------------------
// MiscTableScrollInspector.h
//
//	Interface Builder inspector for MiscTableScroll.
//
//-----------------------------------------------------------------------------
//-----------------------------------------------------------------------------
// $Id: MiscTableScrollInspector.h,v 1.5 99/06/29 07:52:03 sunshine Exp $
// $Log:	MiscTableScrollInspector.h,v $
// Revision 1.5  99/06/29  07:52:03  sunshine
// v140: Converted slot list from matrix of button cells to MiscTableScroll.
// Reworked color controls so user can preview color combinations.  Added
// two text fields; one which previews foreground and background colors for
// unselected slots, and one for selected slots.  This makes better use of
// screen real-estate.
// 
// Revision 1.4  97/12/19  13:12:04  zarnuk
// v133: Eliminated constrain-max, constrain-min is now implicit based on
// presence/absence of auto-size slots.  Eliminated data-sizing.
// Added alignment control.
// 
//  Revision 1.3  95/10/03  23:20:07  zarnuk
//  Now keeps internal "dirty" flag and only does work in
//  "-textDidEnd:endChar:" if the text is "dirty".  This
//  should suppress most of the -border:slotAtPosition:
//  sent to freed object errors from IB.
//-----------------------------------------------------------------------------
extern "Objective-C" {
#import <apps/InterfaceBuilder.h>
}
#import <misckit/MiscTableTypes.h>

@class Button, Matrix, NXColorWell, TextField;
@class MiscTableScroll;
class MiscTableBorder;

@interface MiscTableScrollInspector : IBInspector
    {
    Button*		autosizeSwitch;
    Button*		autoSortSwitch;
    Button*		borderPopUp;
    Button*		cellClassPopUp;
    Button*		deleteButton;
    Button*		downButton;
    Button*		draggableSwitch;
    Button*		enabledSwitch;
    Button*		lazySwitch;
    Button*		modePopUp;
    Button*		sizableSwitch;
    Button*		sortTypePopUp;
    Button*		sortDirectionPopUp;
    Button*		titleModePopUp;
    Button*		titlesSwitch;
    Button*		upButton;
    Button*		userSizeableSwitch;
    Matrix*		alignMatrix;
    MiscTableScroll*	slotScroll;
    TextField*		alignTitle;
    TextField*		sizeField;
    TextField*		sizeMaxField;
    TextField*		sizeMinField;
    TextField*		titleField;
    TextField*		uniformSizeField;
    NXColorWell*	colorText;
    NXColorWell*	colorTextHighlight;
    NXColorWell*	colorBack;
    NXColorWell*	colorBackHighlight;
    TextField*		sampleTextNormal;
    TextField*		sampleTextHighlight;
    int			slot;		// Currently selected slot, or -1.
    int			num_slots;	// Total number of columns.
    MiscBorderType	border_type;
    MiscTableBorder*	border;
    BOOL		dirty;
    }

- (id)init;
- (id)ok:(id)sender;
- (id)revert:(id)sender;

@end

#endif	// __MiscTableScrollInspector_h
